aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--alsa-binding/Alsa-ApiHat.h7
-rw-r--r--conf.d/cmake/config.cmake9
2 files changed, 9 insertions, 7 deletions
diff --git a/alsa-binding/Alsa-ApiHat.h b/alsa-binding/Alsa-ApiHat.h
index 59a9b0c..b5d3866 100644
--- a/alsa-binding/Alsa-ApiHat.h
+++ b/alsa-binding/Alsa-ApiHat.h
@@ -35,11 +35,12 @@
#define STATIC static
#ifndef CONTROL_MAXPATH_LEN
- #define CONTROL_MAXPATH_LEN 255
+ #define CONTROL_MAXPATH_LEN 255
#endif
-#define NO_CARD_SELECTED -1
-#define NO_DEVICE_SELECTED -1
+#define NO_CARD_SELECTED -1
+#define NO_DEVICE_SELECTED -1
+#define NO_SUBDEVICE_SELECTED -1
typedef enum {
QUERY_QUIET =0,
diff --git a/conf.d/cmake/config.cmake b/conf.d/cmake/config.cmake
index cad98ee..27b0dfd 100644
--- a/conf.d/cmake/config.cmake
+++ b/conf.d/cmake/config.cmake
@@ -110,10 +110,11 @@ set(COMPILE_OPTIONS
-fdata-sections
-fPIC
# Personal compilation options
--DMAX_SND_CARD=32 # default ALSA max cards
--DMAX_CARD_DEVICES=32 # 32 devices by sound card should be enough (more investigation needed about this)
--DMAX_LINEAR_DB_SCALE=24 # until 24db volume normalisation use a simple linear scale
--DTLV_BYTE_SIZE=256 # Alsa use 4096 as default but 256 should fit most sndcards
+-DMAX_SND_CARD=32 # default ALSA max cards
+-DMAX_CARD_DEVICES=32 # 32 devices by sound card should be enough (more investigation needed about this)
+-DMAX_DEVICE_SUBDEVICES=8 # 8 subdevices by device should be enough (more investigation needed about this)
+-DMAX_LINEAR_DB_SCALE=24 # until 24db volume normalisation use a simple linear scale
+-DTLV_BYTE_SIZE=256 # Alsa use 4096 as default but 256 should fit most sndcards
-DCONTROL_MAXPATH_LEN=255
CACHE STRING "Compilation flags")
#set(C_COMPILE_OPTIONS "" CACHE STRING "Compilation flags for C language.")